.. _guide:

============
 User Guide
============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 1

    application
    tasks
    calling
    canvas
    workers
    daemonizing
    periodic-tasks
    routing
    monitoring
    security
    optimizing
    debugging
    concurrency/index
    signals
    testing
    extending
    configuration
